;--------------------------------------------------------------------------
; crt0.s - Generic crt0.s for a Z80
;
; Written by Christian Julius in 10.2014 for a Minimum Z80 System
; with Mostek 3801 Multi I/O Chip
;--------------------------------------------------------------------------

	.module crt0			; Modul Name fr den Linker
 
	; Memory Map Adressen der Zeropage (vom Benutzer definierbar)
	; 0x00 					Reset Vector und Aufruf Hauptprogramm
	; 0x38					Mode 1 Int Vektor
	; 0x40					Mode 2 Vektor Tabelle fr STI Mostek Multi I/O
	; 0x66					NMI Reset Vektor
	; 0x80					Copyright String
	; 0x100					User Programm

	; Definitions
	stack  				= 0xffff	; fix
	adr_vec_table		= 0x40		; frei
	adr_copyright       = 0x80		; frei
	adr_nmi				= 0x66		; fix

	; Globale Funktionen und Variablen fr das C-Programm

    .globl	_main
	.globl l__INITIALIZER
    .globl s__INITIALIZER
    .globl s__INITIALIZED

	; -------------------------------------------------------------

	.area	_HEADER (ABS)	
	; Reset vector bei Kaltstart und Sprung ins User Programm
	.org 	0
	 jp init
	

	;; ------- Start des Hauptprogramms nach der Zeropage  -----------
	.org 0x80
init:
	
	ld	sp,#stack	;; Stack an Spitze des RAM legen
	
	; Ram ausnullen
	xor     a             ; clear a and carry
	ld      bc,#0xdfff    ; ram size left
	ld      hl,#0x2000    ; starting from 2000
	ld      de,#0x2001
	ld      (hl),a		  ; 0 -> (2000)	
	ldir                  ; (HL) -> (DE)
	
	; Explicitly initialized global variables.
	ld  bc, #l__INITIALIZER
	ld  a, b
	or  a, c
	jr  Z, gs1
	ld  de, #s__INITIALIZED
	ld  hl, #s__INITIALIZER
	ldir
 gs1:
 
	jp 	_main		; ###### Hauptprogramm aufrufen #######
endlos:
	jr endlos		; Sicher ist sicher

	;; Ordering of segments for the linker.
	.area	_CODE
	.area   _HEADER
	.area   _HEADER0
	.area   _HEADER1
	.area   _HEADER2
	.area   _HEADER3
	.area   _HEADER4
	.area   _HOME
	.area	_INITIAL
	.area   _INITILIZER
	.area	_GSINIT
	.area	_GSFINAL
	.area	_DATA
	.area	_BSEG
	.area	_BSS
	.area   _HEAP

 
	
	
	
	
