#include "main.h"

/////////////////////////////////////////////////////////
// Halte CPU an und lasse LED leuchten
// Ausstieg nur durch Reset
void stop_cpu() __naked
{
	__asm
		 halt
	__endasm ; 

	while (1);
}

/////////////////////////////////////////////////////////
// Zeichenausgabe fr printf auf der STI mit 9600 Baud
void putchar(char c)
{
	while ((STI_TSR & 0x80) == 0); 	// Warte bis Buffer frei...
	STI_UDR = c;					// Byte einschreiben

}

/////////////////////////////////////////////////////////
// Zeichenketten ausgabe auf Uart
void printstrng(char *k)
{
	while ((*k) != '\0')
		putchar(*(k++));
}




/////////////////////////////////////////////////////////
// Stellt eine Hexadezimale Zahl auf dem 7 Segment dar
// i = 255 = Display aus
void SetDigit(uint8_t i)
{
	if (i<=0x0f)
		SEG7 = digits[i];
	else 
		SEG7 = 0xff;		// Display aus
}

/////////////////////////////////////////////////////////
// Setze oder lsche einen GPIO Port
// Input: Port Nr, HIGH oder LOW
void Set_GPIO(uint8_t bitnr, bool stat)
{
	uint8_t foo;
	
	foo = STI_GPIP;			// Register kann nur geladen werden
	if (stat)  		// Bit ein
		foo |= (1<<bitnr);
	else			// Bit lschen
		foo &= ~(1<<bitnr);
		
	STI_GPIP = foo;
}

/////////////////////////////////////////////////////////
// Setze oder lsche eine LED (0..7) am Port A
// Input: Led Nr, HIGH oder LOW
void SetLed(uint8_t lednr, bool stat)
{
	uint8_t foo;
	
	// Read...
	foo = PIO8255_PORT_A;
	// Modify...
	if (stat==TRUE)  // LED ein = Bit LOW
		foo &= ~(1<<lednr);
	else
		foo |= (1<<lednr);
	// Write...		
	PIO8255_PORT_A = foo;
}

/////////////////////////////////////////////////////////
// Stelle ein ganzes Byte auf der LED Zeile dar
void SetLedByte(uint8_t t)
{
	PIO8255_PORT_A 	= ~t;
}

/////////////////////////////////////////////////////////
// Zeitverzgerung 
void delay(uint16_t cnt) {
	volatile uint16_t k;
	for (k=0;k<cnt;k++);
}

/*
	Stelle die Peripheriebausteine ein
*/


/////////////////////////////////////////////////////////
/*
	Eingabe   
	Init:	   1,LINKS oder RECHTS
	Links:	   0,LINKS
	Rechts:	   0,RECHTS
	
	Rotiert eine LED bei jedem Aufruf eins weiter
	
*/
void LED_Rotate(uint8_t i, uint8_t k)
{
	uint8_t merk;
	
	// Init, LED links oder Rechts setzen
	if (i==1)
	{
		if  (k==LINKS)
			PIO8255_PORT_A 	= ~0x01;
		else
			PIO8255_PORT_A 	= ~0x80;
	}
	else // Rotieren lassen bei jedem Aufruf
	{
		merk = ~PIO8255_PORT_A;
		
		if (k==LINKS)
		{
			if (merk!=0x80)
				merk = merk << 1;
			else		
				merk = 0x01;
		}
		
		if (k==RECHTS)
		{
			if (merk!=0x01)
				merk = merk >> 1;
			else		
				merk = 0x80;
			
		}
		
		// Zurck schreiben
		PIO8255_PORT_A = ~merk;	
	}

}